#
# spec file for package go-containerregistry
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


Name:           go-containerregistry
Version:        0.20.1
Release:        1.2
Summary:        Container Library and tools for working with container registries
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/google/go-containerregistry
Source:         https://github.com/google/go-containerregistry/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang-packaging
BuildRequires:  golang(API) = 1.21
Conflicts:      distribution-registry

%description
This is a golang library for working with container registries.

%package -n crane
Summary:        CLI tool for interacting with remote images and registries
Group:          System/Management

%description -n crane
Useful tips and things you can do with crane and other standard tools.

List files in an image
crane export registry.opensuse.org/opensuse/tumbleweed - | tar -tvf - | less

Export a file from an image
crane export registry.opensuse.org/opensuse/tumbleweed -  | tar -0xf - etc/passwd

Diff two configs
diff -u <(crane config busybox:1.32 | jq) <(crane config busybox:1.33 | jq)

Diff two manifests
diff -u <(crane manifest busybox:1.32 | jq) <(crane manifest busybox:1.33 | jq)

Diff filesystem contents
diff -u \
   <(crane export gcr.io/kaniko-project/executor:v1.6.0-debug - | tar -tvf - | sort) \
   <(crane export gcr.io/kaniko-project/executor:v1.7.0-debug - | tar -tvf - | sort)

%package -n crane-bash-completion
Summary:        Bash Completion for crane
Group:          System/Shells
Requires:       bash-completion
Requires:       crane = %{version}
Supplements:    (crane and bash-completion)
BuildArch:      noarch

%description -n crane-bash-completion
Bash command line completion support for crane.

%package -n crane-fish-completion
Summary:        Fish Completion for crane
Group:          System/Shells
Requires:       crane = %{version}
Supplements:    (crane and fish)
BuildArch:      noarch

%description -n crane-fish-completion
Fish command line completion support for crane.

%package -n crane-zsh-completion
Summary:        Zsh Completion for crane
Group:          System/Shells
Requires:       crane = %{version}
Supplements:    (crane and zsh)
BuildArch:      noarch

%description -n crane-zsh-completion
zsh command line completion support for crane.

%package -n gcrane
Summary:        GCR-specific variant of crane
Group:          System/Management

%description -n gcrane
crane is a GCR-specific variant of crane that has richer output for the ls
subcommand and some basic garbage collection support.

%package -n gcrane-bash-completion
Summary:        Bash Completion for gcrane
Group:          System/Shells
Requires:       bash-completion
Requires:       gcrane = %{version}
Supplements:    (gcrane and bash-completion)
BuildArch:      noarch

%description -n gcrane-bash-completion
Bash command line completion support for gcrane.

%package -n gcrane-fish-completion
Summary:        Fish Completion for gcrane
Group:          System/Shells
Requires:       gcrane = %{version}
Supplements:    (gcrane and fish)
BuildArch:      noarch

%description -n gcrane-fish-completion
Fish command line completion support for gcrane.

%package -n gcrane-zsh-completion
Summary:        Zsh Completion for gcrane
Group:          System/Shells
Requires:       gcrane = %{version}
Supplements:    (gcrane and zsh)
BuildArch:      noarch

%description -n gcrane-zsh-completion
zsh command line completion support for gcrane.

%prep
%setup -qa1
%autopatch -p1

%build
for i in crane gcrane registry; do
    go build -mod=vendor -buildmode=pie -trimpath ./cmd/$i
done

%install
find -name crane
for bin in crane gcrane registry; do
    install $bin -D %{buildroot}/%{_bindir}/$bin
done
# "only one tool per thing" SLE15 policy conflicts
%if 0%{?suse_version} && %{?suse_version} < 1550
rm -v %{buildroot}/%{_bindir}/registry
%endif

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/crane completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/crane

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/crane completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/crane.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/crane completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_crane

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/gcrane completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/gcrane

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/gcrane completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/gcrane.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/gcrane completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_gcrane

%if %{?suse_version} > 1500
%files
%license LICENSE
%doc README.md
%{_bindir}/registry
%endif

%files -n crane
%license LICENSE
%{_bindir}/crane

%files -n crane-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/crane

%files -n crane-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/crane.fish

%files -n crane-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_crane

%files -n gcrane
%license LICENSE
%{_bindir}/gcrane

%files -n gcrane-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/gcrane

%files -n gcrane-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/gcrane.fish

%files -n gcrane-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_gcrane

%changelog
* Thu Jul 18 2024 Dirk Müller <dmueller@suse.com>
- update to 0.20.1:
  * Create `remote.Push`
- update to 0.20.0:
  * Referrer API must return correct Content-Type
  * POTENTIALLY BREAKING: Restore blind-write to remote.Put
- update to 0.19.2:
  * Add JSON marshalling funcs for Digest.
  * registry: Implement Range requests for blobs
  * Support podman auth file REGISTRY_AUTH_FILE.
  * feat: crane mutate platform
  * Add Context support to auth methods
  * Fix windows race condition when writing image with duplicate
    layers
  * Add -O shorthand for --omit-digest-tags to crane.
- update to 0.19.1:
  * Bump golang.org/x/net from 0.10.0 to 0.17.0 in
    /pkg/authn/k8schain
  * Bump golang.org/x/ packages
- update to 0.19.0:
  * Work around docker v25 tarballs
- update to 0.18.0:
  * fix: goreleaser config
  * Always print pushed digest in crane push
* Fri May 31 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- add completion subpackages (bash, fish, zsh)
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 0.17.0:
  * Validate index architectures match children
  * Set Content-Length for blob uploads
  * Don't wrap DefaultKeychain with refreshes
  * Build releases with Go 1.21
  * fix: mimic oci-layout in diskblobhandler
  * tag: add command explanation to the long help
  * feat: implement gc command
  * feat: allow port and disk path to be overriden
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 0.16.1:
  * bump deps using ./hack/bump-deps.sh
  * Allow crane to export schema 1 images
  * fixed a goroutine leak
  * retry HTTP 522 errors by default
  * Limit size of manifest
  * Add crane auth token
  * Bump codecov/codecov-action from 3.1.3 to 3.1.4
  * Pass scopes through crane auth token
  * fix: add bounds checking to addendum layer mutations to
    prevent panic
  * Surface better error messages in crane index
  * crane: add missing name option in crane index commands
  * crane: Respect cmd.OutOrStdout
  * Make ErrSchema1 checkable via errors.Is()
  * Don't load into daemon if the image already exists
  * add --blobs-to-disk to 'crane registry serve'
  * Correct crane registry help text
  * Allow concurrent blob Sets, use RWMutex
  * Use RWLock, limit scope of locking, write digest first
  * Let the filesystem handle atomicity
  * Don't try cross-origin mounting against dockerhub
  * Drop localhost to support crane registry serve in a container
  * Return OCI Index content-type for referrers response
  * Allow crane edit to generate non-image artifacts
  * Allow setting Content-Type in crane edit manifest
  * Avoid v1.Manifest in crane edit config (#1583)
  * Support for OCI 1.1+ referrers via API (#1546)
  * Support for OCI 1.1+ referrers via fallback tag
  * Update descriptor "data" field (when valid) during
    "crane edit config" (#1584)
  * Update release.yml (#1540)
  * authn: also read mount secrets (#1560)
  * bump deps using ./hack/bump-deps.sh (#1592)
  * crane: add --flatten for index append (#1566)
  * crane: add serve subcommand (#1586)
  * crane: support --omit-digest-tags in crane ls
  * fix(mutate): also set timestamps only present in
    some formats (#1550)
  * fix: Fix the crane release url and add more steps
  * hash: use generic instantiation (#1538)
  * replace manual slsa-verifier installation with
    action (#1585)
  * skip tls verification if default transport is used
    with insecure option (#1559)
  * tarball: pass imageToTags (#1563)
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 0.12.1:
  * Fix context.DeadlineExceeded comparison (#1488)
  * Fix missing body.Close() in bearer auth (#1482)
  * bump version of slsa generator (#1468)
  * crane: add catalog argument use annotation (#1473)
  * k8schain: Log and proceed if secret or SA are not found
* Tue Dec 13 2022 Dirk Müller <dmueller@suse.com>
- avoid file conflict on SLE15 and other older distributions
* Fri Oct 21 2022 Dirk Müller <dmueller@suse.com>
- Initial package
